///////////////////////////////////////////////////////////////////////////////
//
//    (C) Copyright 2011 EaseFilter Technologies Inc.
//    All Rights Reserved
//
//    This software is part of a licensed software product and may
//    only be used or copied in accordance with the terms of that license.
//
///////////////////////////////////////////////////////////////////////////////

// CPlusPlusDemo.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include "Tools.h"
#include "FilterAPI.h"
#include "UnitTest.h"
#include "AESEncryption.h"
#include <Sddl.h>

#define	MAX_ERROR_MESSAGE_SIZE	1024

#define PrintMessage	wprintf //ToDebugger

VOID
__stdcall
DisconnectCallback();

BOOL
__stdcall
MessageCallback(
   IN		PMESSAGE_SEND_DATA pSendMessage,
   IN OUT	PMESSAGE_REPLY_DATA pReplyMessage);

void 
SendConfigInfoToFilter(ULONG FilterType,WCHAR* FilterFolder,ULONG IoRegistration ,ULONG AccessFlag,UCHAR* encryptionKey = NULL,ULONG keyLength = 0);

SERVICE_STATUS        g_ServiceStatus = {0};
SERVICE_STATUS_HANDLE g_StatusHandle = NULL;
HANDLE                g_ServiceStopEvent = INVALID_HANDLE_VALUE;

int StartWindowsService();
VOID WINAPI ServiceMain (DWORD argc, LPTSTR *argv);
VOID WINAPI ServiceCtrlHandler (DWORD);
DWORD WINAPI ServiceWorkerThread (LPVOID lpParam);
#define SERVICE_NAME  _T("EaseFilter Service")


VOID
Usage (
    VOID
    )
/*++

Routine Description

    Prints usage

Arguments

    None

Return Value

    None

--*/
{

	printf( "\nUsage:		CPlusPlusDemo  [command] <FilterFolder> <IoRegistration> <AccessFlag>\n" );
	printf( "\nCommands:\n" );
	printf( "		i ----- Install Driver\n" );
	printf( "		u ----- UnInstall Driver\n" );
	printf( "		t ----- Driver UnitTest\n" );
	printf( "		m ----- Start monitor filter,require FilterFolder,IoRgistration, if it is empty,it will use default value.\n" );
	printf( "		c ----- Start control filter,require FilterFolder,IoRgistration,AccessFlag if it is empty,it will use default value.\n" );
	printf( "		e ----- Start encryption filter driver test,require FilterFolder,if it is empty,it will use default value.\n" );
	printf( "\n		[FilterFolder]---- the folder mask which will be monitored. By default is c:\\filterTest\\*\n" );
	printf( "		[IoRegistration]---- the I/O requests register to filter. By default is all post I/O.\n" );
	printf( "		[AccessFlag]---- the I/O access flag,only affect control filter. By default is ALLOW_MAX_RIGHT_ACCESS.\n" );
	printf( "\r\nExample: CPlusPlusDemo i   ----- Install Driver\r\n" ); 
	printf( "CPlusPlusDemo u   ----- UnInstall Driver\r\n" ); 
	printf( "CPlusPlusDemo t   ----- Driver UnitTest\r\n" ); 
	printf( "CPlusPlusDemo m c:\\filterTest\\*    ----- run the monitor filter driver\r\n" );
	
}


int _tmain(int argc, _TCHAR* argv[])
{
    DWORD	threadCount = 5;
	ULONG	filterType = FILE_SYSTEM_MONITOR;
	BOOL	ret = FALSE;
	
	//Purchase a license key with the link: http://www.EaseFilter.com/Order.htm
    //Email us to request a trial key: info@EaseFilter.com //free email is not accepted.

	char*	registerKey = "*******************************";

	if(argc <= 1)
	{
		Usage();
		return 1;
	}

	TCHAR op = *argv[1];

	switch(op)
	{
			/*How to run as windows service, do the following steps:
		    
			1.Create windows service:  sc create filterService binpath=  c:\easefilter\x64\cplusplusdemo.exe w  , replace the path with your own path,Note: binpath=(space)
			2. cplusplusdemo.exe i  //install the driver manully. 
			3. Sc start easefilter  //start the windows service.

			*/

		case 'w': ; //start windows service for the monitor filter
				  {
					  StartWindowsService();
					  break;
				  }

		case 'i': //install driver
		{
			//Install the driver only once.
			//After the installation, you can use command "fltmc unload EaseFlt" to unload the driver
			//or "fltmc load EaseFlt" to load the driver, or "fltmc" to check the status of the driver.
			ret = InstallDriver();	
			if( !ret )
			{
				PrintLastErrorMessage( L"InstallDriver failed.");
				return 1;
			}
			break;
		}

		case 'u': //uninstall driver
		{
			ret = UnInstallDriver();
			if( !ret )
			{
				PrintLastErrorMessage( L"UnInstallDriver failed.");
				return 1;
			}

			break;

		}

		case 't': //driver unit test 
		{
			ret = SetRegistrationKey(registerKey);
			if( !ret )
			{
				PrintLastErrorMessage( L"SetRegistrationKey failed.");
				return 1;
			}

			ret = RegisterMessageCallback(threadCount,MessageCallback,DisconnectCallback);

			if( !ret )
			{
				PrintLastErrorMessage( L"RegisterMessageCallback failed.");
				return 1;
			}

			//this the demo how to use the control filter.
			FilterDriverUnitTest();

			Disconnect();

			break;

		}

		case 'c': filterType = FILE_SYSTEM_CONTROL; //start control filter		
		case 'm':
		{

			/*ret = InstallDriver();	
			if( !ret )
			{
				PrintLastErrorMessage( L"InstallDriver failed.");
				return 1;
			}*/

			TCHAR* filterFolder = GetFilterMask();
			ULONG ioRegistration = 0;
			ULONG accessFlag = ALLOW_MAX_RIGHT_ACCESS;			

			if( argc >= 3 )
			{
				filterFolder = argv[2];
			}
			
			if( argc >= 4 )
			{
				ioRegistration = _ttoi(argv[3]);
			}
			else
			{
				//Register the I/O request,which will be monitored or will be called back from filter.
				for (int i = 0; i < MAX_REQUEST_TYPE; i++ )
				{
					//register all post request
					if( (double)i/2 != i/2 )
					{
						ioRegistration |= 1<<i;
					}
				}     
			}

			if( argc >= 5 )
			{
				accessFlag = _ttoi(argv[4]);
			}


			_tprintf(_T("Start Monitor %s  ioregistration:0X%0X accessFlag:0X%0X\n\n Press any key to stop.\n"),filterFolder,ioRegistration,accessFlag);

			ret = SetRegistrationKey(registerKey);
			if( !ret )
			{
				PrintLastErrorMessage( L"SetRegistrationKey failed.");
				return 1;
			}

			ret = RegisterMessageCallback(threadCount,MessageCallback,DisconnectCallback);

			if( !ret )
			{
				PrintLastErrorMessage( L"RegisterMessageCallback failed.");
				return 1;
			}

			//this the demo how to use the control filter.
			SendConfigInfoToFilter(filterType,filterFolder,ioRegistration,accessFlag);

			system("pause");

			Disconnect();

			break;

		}
		case 'e':  //encryption filter driver test
		{

			UnInstallDriver();
			
			ret = InstallDriver();	
			if( !ret )
			{
				PrintLastErrorMessage( L"InstallDriver failed.");
				return 1;
			}

			TCHAR* filterFolder = GetFilterMask();
			ULONG ioRegistration = 0;
			ULONG accessFlag = ALLOW_MAX_RIGHT_ACCESS;			

			if( argc >= 3 )
			{
				filterFolder = argv[2];
			}
			
			ioRegistration = 0;
			accessFlag = FILE_ENCRYPTION_RULE;
			filterType = FILE_SYSTEM_ENCRYPTION;			

			ret = SetRegistrationKey(registerKey);
			if( !ret )
			{
				PrintLastErrorMessage( L"SetRegistrationKey failed.");
				return 1;
			}

			ret = RegisterMessageCallback(threadCount,MessageCallback,DisconnectCallback);

			if( !ret )
			{
				PrintLastErrorMessage( L"RegisterMessageCallback failed.");
				return 1;
			}

			// 32bytes encrytpion key
			UCHAR key[] = {0x60,0x3d,0xeb,0x10,0x15,0xca,0x71,0xbe,0x2b,0x73,0xae,0xf0,0x85,0x7d,0x77,0x81,0x1f,0x35,0x2c,0x07,0x3b,0x61,0x08,0xd7,0x2d,0x98,0x10,0xa3,0x09,0x14,0xdf,0xf4};

			//this the demo how to use the control filter.
			SendConfigInfoToFilter(filterType,filterFolder,ioRegistration,accessFlag,key,sizeof(key));

			//this the demo how to use the control filter.
			EncryptionUnitTest();
			
			_tprintf(_T("\n\nStart Encryption for folder %s,\r\nAll new created files in this folder will be encrypted by filter driver. When filter driver is stopped, the encrypted files can't be read. \n\n Press any key to stop the filter driver.\n"),filterFolder);
			system("pause");

			Disconnect();

			break;

		}
		default:
			{
				Usage(); 
				return 1;
			}


	}

		
	return 0;
}




VOID
PrintMessageInfo( IN	PMESSAGE_SEND_DATA pSendMessage )
{
	WCHAR userName[MAX_PATH];
	WCHAR domainName[MAX_PATH];

	int userNameSize = MAX_PATH;
	int domainNameSize = MAX_PATH;
	SID_NAME_USE snu;

	__try
	{
		BOOL ret = LookupAccountSid( NULL,
									pSendMessage->Sid,
									userName,
									(LPDWORD)&userNameSize,
									domainName,
									(LPDWORD)&domainNameSize,
									&snu); 
	
		if( pSendMessage->Status > STATUS_ERROR )
		{
			ChangeColour(FOREGROUND_RED);
		}
		else if ( pSendMessage->Status > STATUS_WARNING )
		{
			ChangeColour(FOREGROUND_RED|FOREGROUND_GREEN);
		}

		
		PrintMessage( L"\nId# %d MessageType:0X%0x UserName:%ws\\%ws\nProcessId:%d ThreadId:%d Return Status:%0x\nFileSize:%I64d Attributes:%0x FileName:%ws\n"
			,pSendMessage->MessageId,pSendMessage->MessageType,domainName,userName
			,pSendMessage->ProcessId,pSendMessage->ThreadId,pSendMessage->Status
			,pSendMessage->FileSize,pSendMessage->FileAttributes,pSendMessage->FileName);


		ChangeColour(FOREGROUND_RED|FOREGROUND_GREEN|FOREGROUND_BLUE);
	
		switch( pSendMessage->MessageType )
		{

			case PRE_CREATE:
			case POST_CREATE:
			{
				//for Disposition,ShareAccess,DesiredAccess,CreateOptions Please reference Winddows API CreateFile
				//http://msdn.microsoft.com/en-us/library/aa363858%28v=vs.85%29.aspx

				PrintMessage( L"CreateRequest DesiredAccess=%d Disposition=%d ShareAccess=%d CreateOptions=0x%0x CreateStatus = %d fileName:%ws\n"
					,pSendMessage->DesiredAccess,pSendMessage->Disposition,pSendMessage->ShareAccess,pSendMessage->CreateOptions,pSendMessage->CreateStatus,pSendMessage->FileName);


				////here demo how to open the file which was opening by user for read or write
				//HANDLE  hFile = INVALID_HANDLE_VALUE;

				////open the same file handle,it will bypass the share check.
				//ret = GetFileHandleInFilter(pSendMessage->FileName,GENERIC_READ|GENERIC_WRITE,&hFile);

				//if(!ret)
				//{
				//	PrintLastErrorMessage(L"GetFileHandleInFilter failed.");
				//	break;
				//}
				//else
				//{
				//	PrintMessage( L"Get File Hanle:%p\n"
				//	,hFile);

				//}

				//if( INVALID_HANDLE_VALUE != hFile)
				//{
				//	CloseHandle(hFile);
				//}
			   
			   break;
  			}

			case PRE_QUERY_INFORMATION:
			case POST_QUERY_INFORMATION:
			case PRE_SET_INFORMATION:
			case POST_SET_INFORMATION:
			{
				 //FltQueryInformationFile API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff543439%28v=vs.85%29.aspx
				 //FltSetInformationFile API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff544516%28v=VS.85%29.aspx
				PrintMessage( L"Query/Set information request FileInformationClass = %d oldName:%ws newname:%ws\n"
					,pSendMessage->InfoClass,pSendMessage->FileName,pSendMessage->DataBuffer);

				 //for POST_QUERY_INFORMATION request, the pSendMessage->DataBuffer contains the data which return from the file system.
				 //for PRE_SET_INFORMATION request, the pSendMessage->DataBuffer contains the data which will write down to the file system.
				 
				 break;
			}

			case PRE_QUERY_SECURITY:
			case POST_QUERY_SECURITY:
			case PRE_SET_SECURITY:
			case POST_SET_SECURITY:
			{
				 //FltQuerySecurityObject API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff543441%28v=vs.85%29.aspx
				 //FltSetSecurityObject API,http://msdn.microsoft.com/en-us/library/ff544538
				 PrintMessage( L"Query/Set information request SecurityInformation  = %d \n",pSendMessage->InfoClass);

			/*	LPWSTR strDacl;
				ULONG length = 0;
				BOOL ret = ConvertSecurityDescriptorToStringSecurityDescriptor(pSendMessage->DataBuffer, SDDL_REVISION_1,DACL_SECURITY_INFORMATION, &strDacl, &length);
				DWORD errorCode = 0;
				if(!ret)
				{
					errorCode = GetLastError();
				}
				PrintMessage( L"ret:%d %ws length:%d errorCode:%d\n",ret,strDacl,length,errorCode);
				LocalFree(strDacl);*/

				 //for POST_QUERY_SECURITY request, the pSendMessage->DataBuffer contains the data which return from the file system.
				 //for PRE_SET_SECURITY request, the pSendMessage->DataBuffer contains the data which will write down to the file system.

				 break;
			}


			case PRE_DIRECTORY:
			case POST_DIRECTORY:
			{
				//FltQueryDirectoryFile API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff543433%28v=vs.85%29.aspx
				PrintMessage( L"Browse directory request, DataBuffer:%0x FileInformationClass  = %d \n"	,pSendMessage->DataBuffer,pSendMessage->InfoClass);

				//for POST_DIRECTORY request, the pSendMessage->DataBuffer contains the data which return from the file system.

				 break;
			}

			case PRE_FASTIO_READ:
			case POST_FASTIO_READ:
			case PRE_CACHE_READ:
			case POST_CACHE_READ: 
			case PRE_NOCACHE_READ:
			case POST_NOCACHE_READ:
			case PRE_PAGING_IO_READ:
			case POST_PAGING_IO_READ:
			{
				 //FltReadFile API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff544286%28v=vs.85%29.aspx
				PrintMessage( L"Id#:%d Read requst, Offset = %I64d Length = %d returnLength = %d  \n"
				   ,pSendMessage->MessageId,pSendMessage->Offset,pSendMessage->Length,pSendMessage->DataBufferLength);
			   
			   //display the read data return from file system.
			   //printf("data:%s",pSendMessage->DataBuffer);    //it is ansi code characters
			   //wprintf("data:%ws",pSendMessage->DataBuffer);	//it is unicode characters

				//for post read request, the pSendMessage->DataBuffer contains the data which return from the file system.

			   break;
			}

			case PRE_FASTIO_WRITE:
			case POST_FASTIO_WRITE:
			case PRE_CACHE_WRITE:
			case POST_CACHE_WRITE: 
			case PRE_NOCACHE_WRITE:
			case POST_NOCACHE_WRITE:
			case PRE_PAGING_IO_WRITE:
			case POST_PAGING_IO_WRITE:
			{
				 //FltWriteFile API,http://msdn.microsoft.com/en-us/library/windows/hardware/ff544610%28v=vs.85%29.aspx
				PrintMessage( L"WRITE requst, Offset = %I64d Length = %d returnLength = %d \n"
				   ,pSendMessage->Offset,pSendMessage->Length,pSendMessage->DataBufferLength);
				
			   //display the write data to file system.
			   //printf("data:%s",pSendMessage->DataBuffer);    //it is ansi code characters
			   //wprintf("data:%ws",pSendMessage->DataBuffer);	//it is unicode characters

			   //for pre write request, the pSendMessage->DataBuffer contains the data which will write down to the file system.
				
				break;
			}	

			default: break;
		}

	}
	__except( EXCEPTION_EXECUTE_HANDLER  )
	{
		PrintErrorMessage( L"PrintMessageInfo failed.",GetLastError());     
	}

return ;

}


BOOL 
ProcessControlFilter( IN	PMESSAGE_SEND_DATA pSendMessage,IN OUT	PMESSAGE_REPLY_DATA pReplyMessage )
{
	BOOL ret = TRUE;


	try
	{
		
		switch( pSendMessage->MessageType )
		{
		
		case PRE_CREATE:
			{
				//
				//For reparse file/folder open.
				//
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
				   PrintMessage(L"File:%ws will be redirected to new file:%ws open",pSendMessage->FileName,GetTestReparseFileName());

				   //the file name must be unicode string, file name length must be less than MAX_PATH.
				   memcpy(pReplyMessage->DataBuffer,GetTestReparseFileName(),(ULONG)wcslen(GetTestReparseFileName())*sizeof(WCHAR));
				   pReplyMessage->DataBufferLength =(ULONG)wcslen(GetTestReparseFileName())*sizeof(WCHAR);
				   
				   pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_COMPLETE_PRE_OPERATION|FILTER_DATA_BUFFER_IS_UPDATED;
				   pReplyMessage->ReturnStatus = STATUS_REPARSE;
				}

				break;
			}

		case PRE_QUERY_INFORMATION:
			{
				
				//
				//Return your own information without go down to the file system.
				//
				
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
					FILE_BASIC_INFORMATION basicInfo;

					if( pSendMessage->InfoClass == FileBasicInformation )
					{
						basicInfo.ChangeTime = basicInfo.LastWriteTime 
						= basicInfo.CreationTime = basicInfo.LastAccessTime = GetTestFileTime();

						basicInfo.FileAttributes = FILE_ATTRIBUTE_READONLY;

						memcpy(pReplyMessage->DataBuffer,&basicInfo,sizeof(FILE_BASIC_INFORMATION));
						pReplyMessage->DataBufferLength = sizeof(FILE_BASIC_INFORMATION);

						pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_COMPLETE_PRE_OPERATION|FILTER_DATA_BUFFER_IS_UPDATED;
						pReplyMessage->ReturnStatus = STATUS_SUCCESS;
					}


					//for other information class is the same process.
				}			

				break;

			}
			
		case POST_QUERY_INFORMATION:
			{
				
				//
				//Change the information which returns from the file system.
				//
				
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{				
					if( pSendMessage->InfoClass == FileBasicInformation )
					{
						PFILE_BASIC_INFORMATION basicInfo = (PFILE_BASIC_INFORMATION)pSendMessage->DataBuffer;

						basicInfo->ChangeTime = basicInfo->LastWriteTime = GetTestFileTime();
						basicInfo->FileAttributes |= FILE_ATTRIBUTE_READONLY;

						memcpy(pReplyMessage->DataBuffer,basicInfo,sizeof(FILE_BASIC_INFORMATION));
						pReplyMessage->DataBufferLength = sizeof(FILE_BASIC_INFORMATION);

						pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_DATA_BUFFER_IS_UPDATED;
						pReplyMessage->ReturnStatus = STATUS_SUCCESS;
					}

					//for other information class is the same process.
				}
			

				break;
			}


		case PRE_SET_INFORMATION:
			{
				

				//
				//Change the information before write down to the file system.
				//
				
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
					
					if( pSendMessage->InfoClass == FileBasicInformation )
					{
						PFILE_BASIC_INFORMATION basicInfo = (PFILE_BASIC_INFORMATION)pSendMessage->DataBuffer;

						basicInfo->ChangeTime = basicInfo->LastWriteTime = GetTestFileTime();
						basicInfo->FileAttributes = FILE_ATTRIBUTE_READONLY;

						memcpy(pReplyMessage->DataBuffer,basicInfo,sizeof(FILE_BASIC_INFORMATION));
						pReplyMessage->DataBufferLength = sizeof(FILE_BASIC_INFORMATION);

						pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_DATA_BUFFER_IS_UPDATED;
						pReplyMessage->ReturnStatus = STATUS_SUCCESS;

					}

					//for other information class is the same process.
				}

			
				break;
			}

		//For POST_SET_INFORMATION, you can't change anything, since the data was written to the file system.
	   
		//
		//For PRE_DIRECTORY,you can complete it and return your own directory data,the data structure format
		//must be the same as information class from the request,you can reference POST_DIRECTORY.

		case POST_DIRECTORY:
			{
				//
				//Change the information which returns from the file system.
				//
				if(STATUS_SUCCESS == pSendMessage->Status && IsTestFolder(pSendMessage->FileName) )
				{					


					//here we use FileBothDirectoryInformation as example, for other classes, you can do the same operation.
					if( pSendMessage->InfoClass == FileBothDirectoryInformation )
					{
						memcpy(pReplyMessage->DataBuffer,pSendMessage->DataBuffer,pSendMessage->DataBufferLength);
						pReplyMessage->DataBufferLength = pSendMessage->DataBufferLength;
						pReplyMessage->ReturnStatus = STATUS_SUCCESS;

						PFILE_BOTH_DIR_INFORMATION		fileBothDirInfo = (PFILE_BOTH_DIR_INFORMATION)pReplyMessage->DataBuffer;
						ULONG	returnBufferLength = 0;
						ULONG	totalBufferLength = pReplyMessage->DataBufferLength;

						if( NULL == fileBothDirInfo )
						{
							PrintErrorMessage(L"POST_DIRECTORY return empty databuffer",0);
						}

						BOOL isDatabufferUpdated = FALSE;

						while( fileBothDirInfo )
						{
							ULONG nextOffset = fileBothDirInfo->NextEntryOffset;

							PrintMessage(L"FileName:%ws Attributes:0x%0x FileSize:%I64d\n"
								,fileBothDirInfo->FileName,fileBothDirInfo->FileAttributes,fileBothDirInfo->EndOfFile.QuadPart);

							//You can modify the data of the fileBothDirInfo, but must be careful to change the size of the entry.
							//This structure must be aligned on a LONGLONG (8-byte) boundary. If a buffer contains two or more of these structures, 
							//the NextEntryOffset value in each entry, except the last, falls on an 8-byte boundary. 

							//Test: Hide all the files whose file size greater than 1024 bytes.
							if( fileBothDirInfo->EndOfFile.QuadPart > 1024 )
							{				
								if( nextOffset != 0 )
								{
									PrintMessage(L"File %ws is filtered",fileBothDirInfo->FileName);
									memmove (fileBothDirInfo,(PUCHAR)fileBothDirInfo + nextOffset,totalBufferLength - returnBufferLength - nextOffset );
									isDatabufferUpdated = TRUE;
									continue;
								}
								else
								{
									fileBothDirInfo->NextEntryOffset = 0;
								}
							}

							//Test: Add ReadOnly to the FileAttributes, change FileSize to test file size for all files;
							if(NULL == (fileBothDirInfo->FileAttributes & FILE_ATTRIBUTE_DIRECTORY) )
							{
								PrintMessage(L"File %ws attributs:0x%0x was added ReadOnly,Filesize:%I64d was changed to 1234567890"
									,fileBothDirInfo->FileName,fileBothDirInfo->FileAttributes,fileBothDirInfo->EndOfFile.QuadPart);

								fileBothDirInfo->FileAttributes |= FILE_ATTRIBUTE_READONLY;
								fileBothDirInfo->EndOfFile.QuadPart = GetTestFileSize();
								isDatabufferUpdated = TRUE;
							}

							returnBufferLength += nextOffset;
							
							if( nextOffset == 0)
							{
								returnBufferLength += sizeof(FILE_BOTH_DIR_INFORMATION) + fileBothDirInfo->FileNameLength - sizeof(WCHAR);
								fileBothDirInfo = NULL;
							}
							else
							{
								fileBothDirInfo = (PFILE_BOTH_DIR_INFORMATION)((PUCHAR)fileBothDirInfo + nextOffset);
							}

						}

						pReplyMessage->DataBufferLength = returnBufferLength;

						//if you filter out all the files, you can return no more files status. The system won't generate another request.
						if( returnBufferLength == 0 )
						{
							pReplyMessage->ReturnStatus = STATUS_NO_MORE_FILES;	
						}

						if( isDatabufferUpdated )
						{
							PrintMessage(L"Update directory buffer,original length:%d new length:%d",pSendMessage->DataBufferLength,pReplyMessage->DataBufferLength);
							pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_DATA_BUFFER_IS_UPDATED;
						}
					}
				}

				break;
			}

			case PRE_FASTIO_READ:
			case PRE_CACHE_READ:
			case PRE_NOCACHE_READ:
			case PRE_PAGING_IO_READ:
			{
				//
				//Return your own data without go down to the file system.
				//
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
					ULONG dataLength = (ULONG)strlen(GetReplaceData());

					if( pSendMessage->Length < dataLength )
					{
						dataLength = pSendMessage->Length;
					}

					memcpy(pReplyMessage->DataBuffer,GetReplaceData(),dataLength);
					pReplyMessage->DataBufferLength = dataLength;

					pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_COMPLETE_PRE_OPERATION|FILTER_DATA_BUFFER_IS_UPDATED;
					pReplyMessage->ReturnStatus = STATUS_SUCCESS;
				}

			   break;
			}

			case POST_FASTIO_READ:
			case POST_CACHE_READ: 
			case POST_NOCACHE_READ:
			case POST_PAGING_IO_READ:
			{
				//
				//Modify the data which returns from the file system.
				//
				
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
					
					memcpy(pReplyMessage->DataBuffer,pSendMessage->DataBuffer,pSendMessage->DataBufferLength);
					//merge test data to the beginning of the buffer.
					ULONG dataLength = (ULONG)strlen(GetReplaceData());

					if( pSendMessage->Length < dataLength )
					{
						dataLength = pSendMessage->Length;
					}

					memcpy(pReplyMessage->DataBuffer,GetReplaceData(),dataLength);
					pReplyMessage->DataBufferLength = dataLength;

									
					pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_DATA_BUFFER_IS_UPDATED;
					pReplyMessage->ReturnStatus = STATUS_SUCCESS;
				}


			   break;
			}


			case PRE_FASTIO_WRITE:
			case PRE_CACHE_WRITE:
			case PRE_NOCACHE_WRITE:
			case PRE_PAGING_IO_WRITE:
			{
				//
				//Modiy the write data buffer before it goes down to the file system.
				//
				
				if( IsTestFile(pSendMessage->FileName,pSendMessage->FileNameLength) )
				{
					memcpy(pReplyMessage->DataBuffer,pSendMessage->DataBuffer,pSendMessage->DataBufferLength);
					//merge test data to the beginning of the buffer.
					ULONG dataLength = (ULONG)strlen(GetReplaceData());

					if( pSendMessage->Length < dataLength )
					{
						dataLength = pSendMessage->Length;
					}

					memcpy(pReplyMessage->DataBuffer,GetReplaceData(),dataLength);
					pReplyMessage->DataBufferLength = dataLength;


					pReplyMessage->FilterStatus = FILTER_MESSAGE_IS_DIRTY|FILTER_DATA_BUFFER_IS_UPDATED;
					pReplyMessage->ReturnStatus = STATUS_SUCCESS;
				}

			   break;
			}

			//For post write operation, the data was written to the file system,at this point, we can't change anything.

			default: break;
		
		}
	}
	catch(...)
	{
		PrintErrorMessage( L"ProcessControlFilter exception.",GetLastError());     
		ret = FALSE;
	}

	return ret;
}

BOOL
__stdcall
MessageCallback(
   IN		PMESSAGE_SEND_DATA pSendMessage,
   IN OUT	PMESSAGE_REPLY_DATA pReplyMessage)
{

	BOOL	ret = TRUE;

	PrintMessageInfo(pSendMessage);

	if(pReplyMessage)
	{
		ret = ProcessControlFilter(pSendMessage,pReplyMessage);
	}

	return ret;
}

VOID
__stdcall
DisconnectCallback()
{
	printf("Filter connection was disconnected.\n");
	return;
}


void 
SendConfigInfoToFilter(ULONG FilterType,WCHAR* FilterFolder,ULONG IoRegistration ,ULONG AccessFlag,UCHAR* encryptionKey,ULONG keyLength)
{
   //Reset all filter confing setting.
    ResetConfigData();

	//Set the filter maximum wait time for response from the user mode call back function.
	SetConnectionTimeout(30);       

	//Set the filter type to file system monitor/call back filter.
    SetFilterType(FilterType);

	//Setup the filter rule,filter mask is the folder to be monitored,
	//accessFlag is the I/O access control of the folder, only affect callback filter,
	//reparseMask is the destination folder for reparse file open, only when the accessFlag = REPARSE_FILE_OPEN.

	ULONG accessFlag = AccessFlag;

	//test control filter to exclude the file access 
	//accessFlag = ALLOW_MAX_RIGHT_ACCESS | EXCLUDE_FILE_ACCESS;

	if( FilterFolder )
	{
		if( !AddFilterRule(accessFlag,FilterFolder,L"",keyLength,encryptionKey))
		{
			PrintLastErrorMessage(L"AddFilterRule failed.");
			return;
		}
	}

	accessFlag = REPARSE_FILE_OPEN;
	WCHAR* filterMask = L"c:\\reparsetest\\*"; 
	WCHAR* reparseMask = L"c:\\reparse\\*";
	
    if(!AddFilterRule(accessFlag,filterMask,reparseMask))
	{
		PrintLastErrorMessage(L"AddFilterRule failed.");
		return;
	}

	accessFlag = ALLOW_MAX_RIGHT_ACCESS | HIDE_FILES_IN_DIRECTORY_BROWSING;

    filterMask = L"c:\\hideFilesTest\\*"; 
	reparseMask = L"*.txt";

	if(!AddFilterRule(accessFlag,filterMask,reparseMask))
	{
		PrintLastErrorMessage(L"AddFilterRule failed.");
		return;
	}

	//Exclude the process Id from the filter.
 /*   if(!AddExcludedProcessId(GetCurrentProcessId()))
	{
		PrintLastErrorMessage(L"AddExcludedProcessId failed.");
		return;
	}*/
	
	//Only include process id will be watched,all others processes will be excluded.
	//AddIncludedProcessId(GetCurrentProcessId());
	
	if(!RegisterIoRequest(IoRegistration))
	{
		PrintLastErrorMessage(L"RegisterIoRequest failed.");
		return;
	}
}



int StartWindowsService()
{
    OutputDebugString(_T("EaseFilter Service: Main: Entry"));

    SERVICE_TABLE_ENTRY ServiceTable[] = 
    {
        {SERVICE_NAME, (LPSERVICE_MAIN_FUNCTION) ServiceMain},
        {NULL, NULL}
    };

    if (StartServiceCtrlDispatcher (ServiceTable) == FALSE)
    {
       OutputDebugString(_T("EaseFilter Service: Main: StartServiceCtrlDispatcher returned error"));
       return GetLastError ();
    }

    OutputDebugString(_T("EaseFilter Service: Main: Exit"));
    return 0;
}


VOID WINAPI ServiceMain (DWORD argc, LPTSTR *argv)
{
    DWORD Status = E_FAIL;

    OutputDebugString(_T("EaseFilter Service: ServiceMain: Entry"));

    g_StatusHandle = RegisterServiceCtrlHandler (SERVICE_NAME, ServiceCtrlHandler);

    if (g_StatusHandle == NULL) 
    {
        OutputDebugString(_T("EaseFilter Service: ServiceMain: RegisterServiceCtrlHandler returned error"));
        goto EXIT;
    }

    // Tell the service controller we are starting
    ZeroMemory (&g_ServiceStatus, sizeof (g_ServiceStatus));
    g_ServiceStatus.dwServiceType = SERVICE_WIN32_OWN_PROCESS;
    g_ServiceStatus.dwControlsAccepted = 0;
    g_ServiceStatus.dwCurrentState = SERVICE_START_PENDING;
    g_ServiceStatus.dwWin32ExitCode = 0;
    g_ServiceStatus.dwServiceSpecificExitCode = 0;
    g_ServiceStatus.dwCheckPoint = 0;

    if (SetServiceStatus (g_StatusHandle, &g_ServiceStatus) == FALSE) 
    {
        OutputDebugString(_T("EaseFilter Service: ServiceMain: SetServiceStatus returned error"));
    }

    /* 
     * Perform tasks neccesary to start the service here
     */
    OutputDebugString(_T("EaseFilter Service: ServiceMain: Performing Service Start Operations"));

    // Create stop event to wait on later.
    g_ServiceStopEvent = CreateEvent (NULL, TRUE, FALSE, NULL);
    if (g_ServiceStopEvent == NULL) 
    {
        OutputDebugString(_T("EaseFilter Service: ServiceMain: CreateEvent(g_ServiceStopEvent) returned error"));

        g_ServiceStatus.dwControlsAccepted = 0;
        g_ServiceStatus.dwCurrentState = SERVICE_STOPPED;
        g_ServiceStatus.dwWin32ExitCode = GetLastError();
        g_ServiceStatus.dwCheckPoint = 1;

        if (SetServiceStatus (g_StatusHandle, &g_ServiceStatus) == FALSE)
	    {
		    OutputDebugString(_T("EaseFilter Service: ServiceMain: SetServiceStatus returned error"));
	    }
        goto EXIT; 
    }    

    // Tell the service controller we are started
    g_ServiceStatus.dwControlsAccepted = SERVICE_ACCEPT_STOP;
    g_ServiceStatus.dwCurrentState = SERVICE_RUNNING;
    g_ServiceStatus.dwWin32ExitCode = 0;
    g_ServiceStatus.dwCheckPoint = 0;

    if (SetServiceStatus (g_StatusHandle, &g_ServiceStatus) == FALSE)
    {
	    OutputDebugString(_T("EaseFilter Service: ServiceMain: SetServiceStatus returned error"));
    }

    // Start the thread that will perform the main task of the service
    HANDLE hThread = CreateThread (NULL, 0, ServiceWorkerThread, NULL, 0, NULL);

    OutputDebugString(_T("EaseFilter Service: ServiceMain: Waiting for Worker Thread to complete"));

    // Wait until our worker thread exits effectively signaling that the service needs to stop
    WaitForSingleObject (hThread, INFINITE);
    
    OutputDebugString(_T("EaseFilter Service: ServiceMain: Worker Thread Stop Event signaled"));
    
    
    /* 
     * Perform any cleanup tasks
     */
    OutputDebugString(_T("EaseFilter Service: ServiceMain: Performing Cleanup Operations"));

    CloseHandle (g_ServiceStopEvent);

    g_ServiceStatus.dwControlsAccepted = 0;
    g_ServiceStatus.dwCurrentState = SERVICE_STOPPED;
    g_ServiceStatus.dwWin32ExitCode = 0;
    g_ServiceStatus.dwCheckPoint = 3;

    if (SetServiceStatus (g_StatusHandle, &g_ServiceStatus) == FALSE)
    {
	    OutputDebugString(_T("EaseFilter Service: ServiceMain: SetServiceStatus returned error"));
    }
    
    EXIT:
    OutputDebugString(_T("EaseFilter Service: ServiceMain: Exit"));

    return;
}


VOID WINAPI ServiceCtrlHandler (DWORD CtrlCode)
{
    OutputDebugString(_T("EaseFilter Service: ServiceCtrlHandler: Entry"));

    switch (CtrlCode) 
	{
     case SERVICE_CONTROL_STOP :

        OutputDebugString(_T("EaseFilter Service: ServiceCtrlHandler: SERVICE_CONTROL_STOP Request"));

        if (g_ServiceStatus.dwCurrentState != SERVICE_RUNNING)
           break;

        /* 
         * Perform tasks neccesary to stop the service here 
         */
        
        g_ServiceStatus.dwControlsAccepted = 0;
        g_ServiceStatus.dwCurrentState = SERVICE_STOP_PENDING;
        g_ServiceStatus.dwWin32ExitCode = 0;
        g_ServiceStatus.dwCheckPoint = 4;

        if (SetServiceStatus (g_StatusHandle, &g_ServiceStatus) == FALSE)
		{
			OutputDebugString(_T("EaseFilter Service: ServiceCtrlHandler: SetServiceStatus returned error"));
		}

        // This will signal the worker thread to start shutting down
        SetEvent (g_ServiceStopEvent);

        break;

     default:
         break;
    }

    OutputDebugString(_T("EaseFilter Service: ServiceCtrlHandler: Exit"));
}


DWORD WINAPI ServiceWorkerThread (LPVOID lpParam)
{
    OutputDebugString(_T("EaseFilter Service: ServiceWorkerThread: Entry"));

    //  Periodically check if the service has been requested to stop
    while (WaitForSingleObject(g_ServiceStopEvent, 0) != WAIT_OBJECT_0)
    {        
            BOOL ret = FALSE;
			TCHAR* filterFolder = GetFilterMask();
			ULONG ioRegistration = 0;
			ULONG accessFlag = ALLOW_MAX_RIGHT_ACCESS;		
			DWORD	threadCount = 5;
			ULONG	filterType = FILE_SYSTEM_MONITOR;
			char*	registerKey = "71CD200D-6DD83DB4-47A900C4-1310C7C8-07001C08";

			//Register the I/O request,which will be monitored or will be called back from filter.
			for (int i = 0; i < MAX_REQUEST_TYPE; i++ )
			{
				//register all post request
				if( (double)i/2 != i/2 )
				{
					ioRegistration |= 1<<i;
				}
			}     

			ret = SetRegistrationKey(registerKey);
			if( !ret )
			{
				PrintLastErrorMessage( L"SetRegistrationKey failed.");
				return 1;
			}

			ret = RegisterMessageCallback(threadCount,MessageCallback,DisconnectCallback);

			if( !ret )
			{
				PrintLastErrorMessage( L"RegisterMessageCallback failed.");
				return 1;
			}

			//this the demo how to use the control filter.
			SendConfigInfoToFilter(filterType,filterFolder,ioRegistration,accessFlag);		

    }

	Disconnect();
    OutputDebugString(_T("EaseFilter Service: ServiceWorkerThread: Exit"));

    return ERROR_SUCCESS;
}