﻿
using System;
using System.Text;
using System.Windows.Forms;

namespace CSharpDemo
{
    partial class FilterDemo 
    {
        /// <summary>
        /// Required designer variable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        private MessageInfo messageInfo = null;
        private ConfigSetting configSetting = null;
        private FilterTest filterTest = null;

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }

            if (disposing && (null != messageInfo))
            {
                messageInfo.Dispose();
            }

            base.Dispose(disposing);
        }

        #region Config setting

        void InitConfig()
        {
            messageInfo = new MessageInfo(listView_MessageInfo);
            configSetting = new ConfigSetting(listView_FilterRules, listView_EncryptFilterRule);
            filterTest = new FilterTest();
            EventMessage.SetListViewMessage(listView_Message);            

            textBox_ConnectionTimeout.Text = configSetting.ConnectionTimeOut.ToString();
            textBox_ExcludePID.Text = System.Diagnostics.Process.GetCurrentProcess().Id.ToString() + ";";
            textBox_ConnectionThreads.Text = configSetting.FilterConnectionThreads.ToString();
            textBox_AccessFlag.Text = ((uint)EaseFilter.ALLOW_MAX_RIGHT_ACCESS).ToString();
            textBox_RequestRegistration.Text = configSetting.RequestRegistration.ToString();

        }

        void SendConfigInfoToFilter()
        {
            if (!EaseFilter.IsFilterStarted)
            {
                System.Windows.Forms.MessageBox.Show("Filter is not started yet.");
                return;
            }

            EaseFilter.ResetConfigData();

            EaseFilter.SetConnectionTimeout(configSetting.ConnectionTimeOut);
            EaseFilter.SetFilterType((uint)configSetting.FilterType);

            System.Collections.Generic.List<ConfigSetting.FilterRule> filterRuleList = configSetting.FilterList;
            foreach (ConfigSetting.FilterRule filterRule in filterRuleList)
            {
                byte[] encryptionKey = filterRule.EncryptionKey;
                EaseFilter.AddFilterRule((uint)filterRule.AccessFlag, filterRule.FilterMask, filterRule.ReparseMask, (uint)encryptionKey.Length, encryptionKey);
            }

            foreach (uint excludedPid in configSetting.ExcludedPid)
            {
                EaseFilter.AddExcludedProcessId(excludedPid);
            }

            EaseFilter.RegisterIoRequest(configSetting.RequestRegistration);

        }

        private void button_AddFilterRule_Click(object sender, EventArgs e)
        {
            EaseFilter.AccessFlag accessFlag = (EaseFilter.AccessFlag)uint.Parse(textBox_AccessFlag.Text);
            byte[] encryptionKey = ConvertHexStringToByteArray(textBox_EncryptKey.Text);

            if (encryptionKey != null && encryptionKey.Length != 16 && encryptionKey.Length != 24 && encryptionKey.Length != 32)
            {
                MessageBox.Show("The encryption key length must be 16,24 or 32 bytes", "Key Length", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            if (!configSetting.AddFilterRule(accessFlag, textBox_FilterMask.Text, textBox_ReparseMask.Text, encryptionKey))
            {
                System.Windows.Forms.MessageBox.Show("Filter rule already exist.");
            }
        }

        private void button_RemoveFilter_Click(object sender, EventArgs e)
        {
            foreach (System.Windows.Forms.ListViewItem item in listView_FilterRules.SelectedItems)
            {
                configSetting.RemoveFilterRule(item);
            }
        }


        private void button_ExcludedPID_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Excluded_ProccessId, textBox_ExcludePID.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_ExcludePID.Text = optionForm.ExcludedPid;
            }
            optionForm.Close();

        }

        private void button_RequestRegistration_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Register_Request, textBox_RequestRegistration.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_RequestRegistration.Text = optionForm.RequestRegistration.ToString();
            }
            optionForm.Close();
        }

        private void button_AccessFlag_Click(object sender, EventArgs e)
        {
            OptionForm optionForm = new OptionForm(OptionForm.OptionType.Access_Flag, textBox_AccessFlag.Text);
            if (System.Windows.Forms.DialogResult.OK == optionForm.ShowDialog())
            {
                textBox_AccessFlag.Text = optionForm.AccessFlags.ToString();
            }
            optionForm.Close();

        }


        private void button_ApplySetting_Click(object sender, EventArgs e)
        {
            configSetting.ConnectionTimeOut = uint.Parse(textBox_ConnectionTimeout.Text);
            configSetting.RequestRegistration = uint.Parse(textBox_RequestRegistration.Text);
            configSetting.FilterType = (EaseFilter.FilterType)comboBox_FilterType.SelectedIndex;
            configSetting.FilterConnectionThreads = uint.Parse(textBox_ConnectionThreads.Text);

            System.Collections.Generic.List<uint> pidList = new System.Collections.Generic.List<uint>();

            string[] pids = textBox_ExcludePID.Text.Split(';');
            foreach (string pid in pids)
            {
                if (!string.IsNullOrEmpty(pid))
                {
                    pidList.Add(uint.Parse(pid));
                }
            }

            configSetting.ExcludedPid = pidList;

            if (EaseFilter.IsFilterStarted)
            {
                SendConfigInfoToFilter();
            }
        }

        #endregion

        #region Windows Form Designer generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.TabPage = new System.Windows.Forms.TabControl();
            this.tabPage_FilterMessage = new System.Windows.Forms.TabPage();
            this.splitContainer1 = new System.Windows.Forms.SplitContainer();
            this.listView_MessageInfo = new System.Windows.Forms.ListView();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.button_UnInstallDriver = new System.Windows.Forms.Button();
            this.button_InstallDriver = new System.Windows.Forms.Button();
            this.button_Clear = new System.Windows.Forms.Button();
            this.button_Start = new System.Windows.Forms.Button();
            this.button_Stop = new System.Windows.Forms.Button();
            this.tabPage_Setting = new System.Windows.Forms.TabPage();
            this.splitContainer3 = new System.Windows.Forms.SplitContainer();
            this.splitContainer4 = new System.Windows.Forms.SplitContainer();
            this.button_RequestRegistration = new System.Windows.Forms.Button();
            this.textBox_RequestRegistration = new System.Windows.Forms.TextBox();
            this.textBox_ConnectionThreads = new System.Windows.Forms.TextBox();
            this.label_ConnectionThreads = new System.Windows.Forms.Label();
            this.button_ExcludedPID = new System.Windows.Forms.Button();
            this.comboBox_FilterType = new System.Windows.Forms.ComboBox();
            this.groupBox3 = new System.Windows.Forms.GroupBox();
            this.label17 = new System.Windows.Forms.Label();
            this.label12 = new System.Windows.Forms.Label();
            this.textBox_EncryptionKey = new System.Windows.Forms.TextBox();
            this.label7 = new System.Windows.Forms.Label();
            this.textBox_ReparseMask = new System.Windows.Forms.TextBox();
            this.button_AccessFlag = new System.Windows.Forms.Button();
            this.textBox_FilterMask = new System.Windows.Forms.TextBox();
            this.label6 = new System.Windows.Forms.Label();
            this.label5 = new System.Windows.Forms.Label();
            this.textBox_AccessFlag = new System.Windows.Forms.TextBox();
            this.textBox_ExcludePID = new System.Windows.Forms.TextBox();
            this.textBox_ConnectionTimeout = new System.Windows.Forms.TextBox();
            this.label4 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.label1 = new System.Windows.Forms.Label();
            this.listView_FilterRules = new System.Windows.Forms.ListView();
            this.button_ApplySetting = new System.Windows.Forms.Button();
            this.button_RemoveFilter = new System.Windows.Forms.Button();
            this.button_AddFilterRule = new System.Windows.Forms.Button();
            this.tabPage_Encryption = new System.Windows.Forms.TabPage();
            this.groupBox4 = new System.Windows.Forms.GroupBox();
            this.label16 = new System.Windows.Forms.Label();
            this.button_ApplyEncryptionSetting = new System.Windows.Forms.Button();
            this.button_RemoveEncryptionFilterRule = new System.Windows.Forms.Button();
            this.button_AddEncryptionFilterRule = new System.Windows.Forms.Button();
            this.listView_EncryptFilterRule = new System.Windows.Forms.ListView();
            this.textBox_EncryptionFilterMask = new System.Windows.Forms.TextBox();
            this.button1 = new System.Windows.Forms.Button();
            this.button2 = new System.Windows.Forms.Button();
            this.label10 = new System.Windows.Forms.Label();
            this.textBox_EncryptFilterRuleKey = new System.Windows.Forms.TextBox();
            this.label11 = new System.Windows.Forms.Label();
            this.groupBox2 = new System.Windows.Forms.GroupBox();
            this.button_DeleteIVTag = new System.Windows.Forms.Button();
            this.checkBox_AddIVTag = new System.Windows.Forms.CheckBox();
            this.label15 = new System.Windows.Forms.Label();
            this.label14 = new System.Windows.Forms.Label();
            this.textBox_IV = new System.Windows.Forms.TextBox();
            this.label13 = new System.Windows.Forms.Label();
            this.button_ReadEncryptedFile = new System.Windows.Forms.Button();
            this.button_CopyEncryptedFile = new System.Windows.Forms.Button();
            this.textBox_EncryptFileName = new System.Windows.Forms.TextBox();
            this.button_EncryptFile = new System.Windows.Forms.Button();
            this.button_DecryptFile = new System.Windows.Forms.Button();
            this.label8 = new System.Windows.Forms.Label();
            this.textBox_EncryptionInfo = new System.Windows.Forms.TextBox();
            this.textBox_EncryptKey = new System.Windows.Forms.TextBox();
            this.label9 = new System.Windows.Forms.Label();
            this.tabPage_EncryptionUnitTest = new System.Windows.Forms.TabPage();
            this.groupBox5 = new System.Windows.Forms.GroupBox();
            this.button_StopEncryptionUnitTest = new System.Windows.Forms.Button();
            this.button_EncryptionUnitTest = new System.Windows.Forms.Button();
            this.textBox_EncryptionUnitTestInfo = new System.Windows.Forms.TextBox();
            this.tabPage_EventLog = new System.Windows.Forms.TabPage();
            this.listView_Message = new System.Windows.Forms.ListView();
            this.checkBox_RawHex = new System.Windows.Forms.CheckBox();
            this.TabPage.SuspendLayout();
            this.tabPage_FilterMessage.SuspendLayout();
            this.splitContainer1.Panel1.SuspendLayout();
            this.splitContainer1.Panel2.SuspendLayout();
            this.splitContainer1.SuspendLayout();
            this.groupBox1.SuspendLayout();
            this.tabPage_Setting.SuspendLayout();
            this.splitContainer3.Panel1.SuspendLayout();
            this.splitContainer3.Panel2.SuspendLayout();
            this.splitContainer3.SuspendLayout();
            this.splitContainer4.Panel1.SuspendLayout();
            this.splitContainer4.Panel2.SuspendLayout();
            this.splitContainer4.SuspendLayout();
            this.groupBox3.SuspendLayout();
            this.tabPage_Encryption.SuspendLayout();
            this.groupBox4.SuspendLayout();
            this.groupBox2.SuspendLayout();
            this.tabPage_EncryptionUnitTest.SuspendLayout();
            this.groupBox5.SuspendLayout();
            this.tabPage_EventLog.SuspendLayout();
            this.SuspendLayout();
            // 
            // TabPage
            // 
            this.TabPage.Controls.Add(this.tabPage_FilterMessage);
            this.TabPage.Controls.Add(this.tabPage_Setting);
            this.TabPage.Controls.Add(this.tabPage_Encryption);
            this.TabPage.Controls.Add(this.tabPage_EncryptionUnitTest);
            this.TabPage.Controls.Add(this.tabPage_EventLog);
            this.TabPage.Dock = System.Windows.Forms.DockStyle.Fill;
            this.TabPage.Location = new System.Drawing.Point(0, 0);
            this.TabPage.Name = "TabPage";
            this.TabPage.SelectedIndex = 0;
            this.TabPage.Size = new System.Drawing.Size(1018, 518);
            this.TabPage.TabIndex = 3;
            // 
            // tabPage_FilterMessage
            // 
            this.tabPage_FilterMessage.Controls.Add(this.splitContainer1);
            this.tabPage_FilterMessage.Location = new System.Drawing.Point(4, 22);
            this.tabPage_FilterMessage.Name = "tabPage_FilterMessage";
            this.tabPage_FilterMessage.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_FilterMessage.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_FilterMessage.TabIndex = 0;
            this.tabPage_FilterMessage.Text = "Filter Message";
            this.tabPage_FilterMessage.UseVisualStyleBackColor = true;
            // 
            // splitContainer1
            // 
            this.splitContainer1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer1.Location = new System.Drawing.Point(3, 3);
            this.splitContainer1.Name = "splitContainer1";
            this.splitContainer1.Orientation = System.Windows.Forms.Orientation.Horizontal;
            // 
            // splitContainer1.Panel1
            // 
            this.splitContainer1.Panel1.Controls.Add(this.listView_MessageInfo);
            // 
            // splitContainer1.Panel2
            // 
            this.splitContainer1.Panel2.Controls.Add(this.groupBox1);
            this.splitContainer1.Panel2MinSize = 50;
            this.splitContainer1.Size = new System.Drawing.Size(1004, 486);
            this.splitContainer1.SplitterDistance = 432;
            this.splitContainer1.TabIndex = 5;
            // 
            // listView_MessageInfo
            // 
            this.listView_MessageInfo.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_MessageInfo.FullRowSelect = true;
            this.listView_MessageInfo.GridLines = true;
            this.listView_MessageInfo.HideSelection = false;
            this.listView_MessageInfo.LabelEdit = true;
            this.listView_MessageInfo.Location = new System.Drawing.Point(0, 0);
            this.listView_MessageInfo.MultiSelect = false;
            this.listView_MessageInfo.Name = "listView_MessageInfo";
            this.listView_MessageInfo.ShowItemToolTips = true;
            this.listView_MessageInfo.Size = new System.Drawing.Size(1004, 432);
            this.listView_MessageInfo.TabIndex = 3;
            this.listView_MessageInfo.UseCompatibleStateImageBehavior = false;
            this.listView_MessageInfo.View = System.Windows.Forms.View.Details;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.button_UnInstallDriver);
            this.groupBox1.Controls.Add(this.button_InstallDriver);
            this.groupBox1.Controls.Add(this.button_Clear);
            this.groupBox1.Controls.Add(this.button_Start);
            this.groupBox1.Controls.Add(this.button_Stop);
            this.groupBox1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.groupBox1.Location = new System.Drawing.Point(0, 0);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(1004, 50);
            this.groupBox1.TabIndex = 4;
            this.groupBox1.TabStop = false;
            // 
            // button_UnInstallDriver
            // 
            this.button_UnInstallDriver.Location = new System.Drawing.Point(790, 13);
            this.button_UnInstallDriver.Name = "button_UnInstallDriver";
            this.button_UnInstallDriver.Size = new System.Drawing.Size(86, 23);
            this.button_UnInstallDriver.TabIndex = 4;
            this.button_UnInstallDriver.Text = "UnInstallDriver";
            this.button_UnInstallDriver.UseVisualStyleBackColor = true;
            this.button_UnInstallDriver.Click += new System.EventHandler(this.button_UnInstallDriver_Click);
            // 
            // button_InstallDriver
            // 
            this.button_InstallDriver.Location = new System.Drawing.Point(62, 13);
            this.button_InstallDriver.Name = "button_InstallDriver";
            this.button_InstallDriver.Size = new System.Drawing.Size(75, 23);
            this.button_InstallDriver.TabIndex = 3;
            this.button_InstallDriver.Text = "InstallDriver";
            this.button_InstallDriver.UseVisualStyleBackColor = true;
            this.button_InstallDriver.Click += new System.EventHandler(this.button_InstallDriver_Click);
            // 
            // button_Clear
            // 
            this.button_Clear.Location = new System.Drawing.Point(560, 13);
            this.button_Clear.Name = "button_Clear";
            this.button_Clear.Size = new System.Drawing.Size(124, 23);
            this.button_Clear.TabIndex = 2;
            this.button_Clear.Text = "Clear Message";
            this.button_Clear.UseVisualStyleBackColor = true;
            this.button_Clear.Click += new System.EventHandler(this.button_Clear_Click);
            // 
            // button_Start
            // 
            this.button_Start.Location = new System.Drawing.Point(223, 13);
            this.button_Start.Name = "button_Start";
            this.button_Start.Size = new System.Drawing.Size(91, 23);
            this.button_Start.TabIndex = 0;
            this.button_Start.Text = "Start Filter";
            this.button_Start.UseVisualStyleBackColor = true;
            this.button_Start.Click += new System.EventHandler(this.button_Start_Click);
            // 
            // button_Stop
            // 
            this.button_Stop.Location = new System.Drawing.Point(378, 13);
            this.button_Stop.Name = "button_Stop";
            this.button_Stop.Size = new System.Drawing.Size(75, 23);
            this.button_Stop.TabIndex = 1;
            this.button_Stop.Text = "Stop Filter";
            this.button_Stop.UseVisualStyleBackColor = true;
            this.button_Stop.Click += new System.EventHandler(this.button_Stop_Click);
            // 
            // tabPage_Setting
            // 
            this.tabPage_Setting.Controls.Add(this.splitContainer3);
            this.tabPage_Setting.Location = new System.Drawing.Point(4, 22);
            this.tabPage_Setting.Name = "tabPage_Setting";
            this.tabPage_Setting.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_Setting.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_Setting.TabIndex = 1;
            this.tabPage_Setting.Text = "Filter Setting";
            this.tabPage_Setting.UseVisualStyleBackColor = true;
            // 
            // splitContainer3
            // 
            this.splitContainer3.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer3.Location = new System.Drawing.Point(3, 3);
            this.splitContainer3.Name = "splitContainer3";
            // 
            // splitContainer3.Panel1
            // 
            this.splitContainer3.Panel1.Controls.Add(this.splitContainer4);
            // 
            // splitContainer3.Panel2
            // 
            this.splitContainer3.Panel2.Controls.Add(this.button_ApplySetting);
            this.splitContainer3.Panel2.Controls.Add(this.button_RemoveFilter);
            this.splitContainer3.Panel2.Controls.Add(this.button_AddFilterRule);
            this.splitContainer3.Size = new System.Drawing.Size(1004, 486);
            this.splitContainer3.SplitterDistance = 825;
            this.splitContainer3.TabIndex = 1;
            // 
            // splitContainer4
            // 
            this.splitContainer4.Dock = System.Windows.Forms.DockStyle.Fill;
            this.splitContainer4.Location = new System.Drawing.Point(0, 0);
            this.splitContainer4.Name = "splitContainer4";
            // 
            // splitContainer4.Panel1
            // 
            this.splitContainer4.Panel1.Controls.Add(this.button_RequestRegistration);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_RequestRegistration);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ConnectionThreads);
            this.splitContainer4.Panel1.Controls.Add(this.label_ConnectionThreads);
            this.splitContainer4.Panel1.Controls.Add(this.button_ExcludedPID);
            this.splitContainer4.Panel1.Controls.Add(this.comboBox_FilterType);
            this.splitContainer4.Panel1.Controls.Add(this.groupBox3);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ExcludePID);
            this.splitContainer4.Panel1.Controls.Add(this.textBox_ConnectionTimeout);
            this.splitContainer4.Panel1.Controls.Add(this.label4);
            this.splitContainer4.Panel1.Controls.Add(this.label3);
            this.splitContainer4.Panel1.Controls.Add(this.label2);
            this.splitContainer4.Panel1.Controls.Add(this.label1);
            // 
            // splitContainer4.Panel2
            // 
            this.splitContainer4.Panel2.Controls.Add(this.listView_FilterRules);
            this.splitContainer4.Size = new System.Drawing.Size(825, 486);
            this.splitContainer4.SplitterDistance = 526;
            this.splitContainer4.TabIndex = 1;
            // 
            // button_RequestRegistration
            // 
            this.button_RequestRegistration.Location = new System.Drawing.Point(467, 140);
            this.button_RequestRegistration.Name = "button_RequestRegistration";
            this.button_RequestRegistration.Size = new System.Drawing.Size(30, 23);
            this.button_RequestRegistration.TabIndex = 21;
            this.button_RequestRegistration.Text = "...";
            this.button_RequestRegistration.UseVisualStyleBackColor = true;
            this.button_RequestRegistration.Click += new System.EventHandler(this.button_RequestRegistration_Click);
            // 
            // textBox_RequestRegistration
            // 
            this.textBox_RequestRegistration.Location = new System.Drawing.Point(190, 140);
            this.textBox_RequestRegistration.Name = "textBox_RequestRegistration";
            this.textBox_RequestRegistration.Size = new System.Drawing.Size(271, 20);
            this.textBox_RequestRegistration.TabIndex = 20;
            this.textBox_RequestRegistration.Text = "0";
            // 
            // textBox_ConnectionThreads
            // 
            this.textBox_ConnectionThreads.Location = new System.Drawing.Point(190, 66);
            this.textBox_ConnectionThreads.Name = "textBox_ConnectionThreads";
            this.textBox_ConnectionThreads.Size = new System.Drawing.Size(271, 20);
            this.textBox_ConnectionThreads.TabIndex = 15;
            this.textBox_ConnectionThreads.Text = "5";
            // 
            // label_ConnectionThreads
            // 
            this.label_ConnectionThreads.AutoSize = true;
            this.label_ConnectionThreads.Location = new System.Drawing.Point(28, 73);
            this.label_ConnectionThreads.Name = "label_ConnectionThreads";
            this.label_ConnectionThreads.Size = new System.Drawing.Size(128, 13);
            this.label_ConnectionThreads.TabIndex = 11;
            this.label_ConnectionThreads.Text = "Filter Connection Threads";
            // 
            // button_ExcludedPID
            // 
            this.button_ExcludedPID.Location = new System.Drawing.Point(467, 101);
            this.button_ExcludedPID.Name = "button_ExcludedPID";
            this.button_ExcludedPID.Size = new System.Drawing.Size(30, 23);
            this.button_ExcludedPID.TabIndex = 10;
            this.button_ExcludedPID.Text = "...";
            this.button_ExcludedPID.UseVisualStyleBackColor = true;
            this.button_ExcludedPID.Click += new System.EventHandler(this.button_ExcludedPID_Click);
            // 
            // comboBox_FilterType
            // 
            this.comboBox_FilterType.FormattingEnabled = true;
            this.comboBox_FilterType.Items.AddRange(new object[] {
            "FILE_SYSTEM_MONITOR",
            "FILE_SYSTEM_CONTROL",
            "FILE_SYSTEM_ENCRYPTION",
            "FILE_SYSTEM_CONTROL_ENCRYPTION",
            "FILE_SYSTEM_MONITOR_ENCRYPTION    "});
            this.comboBox_FilterType.Location = new System.Drawing.Point(190, 3);
            this.comboBox_FilterType.Name = "comboBox_FilterType";
            this.comboBox_FilterType.Size = new System.Drawing.Size(271, 21);
            this.comboBox_FilterType.TabIndex = 9;
            this.comboBox_FilterType.Text = "File System Monitor Filter";
            // 
            // groupBox3
            // 
            this.groupBox3.Controls.Add(this.label17);
            this.groupBox3.Controls.Add(this.label12);
            this.groupBox3.Controls.Add(this.textBox_EncryptionKey);
            this.groupBox3.Controls.Add(this.label7);
            this.groupBox3.Controls.Add(this.textBox_ReparseMask);
            this.groupBox3.Controls.Add(this.button_AccessFlag);
            this.groupBox3.Controls.Add(this.textBox_FilterMask);
            this.groupBox3.Controls.Add(this.label6);
            this.groupBox3.Controls.Add(this.label5);
            this.groupBox3.Controls.Add(this.textBox_AccessFlag);
            this.groupBox3.Location = new System.Drawing.Point(0, 191);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(520, 216);
            this.groupBox3.TabIndex = 8;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "Filter Rule";
            // 
            // label17
            // 
            this.label17.AutoSize = true;
            this.label17.Location = new System.Drawing.Point(178, 138);
            this.label17.Name = "label17";
            this.label17.Size = new System.Drawing.Size(250, 13);
            this.label17.TabIndex = 24;
            this.label17.Text = "(Encryption Key Length Must Be 16, 24 or 32 bytes)";
            // 
            // label12
            // 
            this.label12.AutoSize = true;
            this.label12.Location = new System.Drawing.Point(25, 154);
            this.label12.Name = "label12";
            this.label12.Size = new System.Drawing.Size(130, 13);
            this.label12.TabIndex = 23;
            this.label12.Text = "EncryptionKey(Hex String)";
            // 
            // textBox_EncryptionKey
            // 
            this.textBox_EncryptionKey.Location = new System.Drawing.Point(181, 154);
            this.textBox_EncryptionKey.Name = "textBox_EncryptionKey";
            this.textBox_EncryptionKey.Size = new System.Drawing.Size(277, 20);
            this.textBox_EncryptionKey.TabIndex = 22;
            this.textBox_EncryptionKey.Text = "603deb1015ca71be2b73aef0857d77811f352c073b6108d72d9810a30914dff4";
            // 
            // label7
            // 
            this.label7.AutoSize = true;
            this.label7.Location = new System.Drawing.Point(25, 103);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(101, 13);
            this.label7.TabIndex = 21;
            this.label7.Text = "Reparse Filter Mask";
            // 
            // textBox_ReparseMask
            // 
            this.textBox_ReparseMask.Location = new System.Drawing.Point(187, 96);
            this.textBox_ReparseMask.Name = "textBox_ReparseMask";
            this.textBox_ReparseMask.Size = new System.Drawing.Size(271, 20);
            this.textBox_ReparseMask.TabIndex = 20;
            this.textBox_ReparseMask.Text = "c:\\Reparse*";
            // 
            // button_AccessFlag
            // 
            this.button_AccessFlag.Location = new System.Drawing.Point(464, 28);
            this.button_AccessFlag.Name = "button_AccessFlag";
            this.button_AccessFlag.Size = new System.Drawing.Size(30, 23);
            this.button_AccessFlag.TabIndex = 10;
            this.button_AccessFlag.Text = "...";
            this.button_AccessFlag.UseVisualStyleBackColor = true;
            this.button_AccessFlag.Click += new System.EventHandler(this.button_AccessFlag_Click);
            // 
            // textBox_FilterMask
            // 
            this.textBox_FilterMask.Location = new System.Drawing.Point(187, 60);
            this.textBox_FilterMask.Name = "textBox_FilterMask";
            this.textBox_FilterMask.Size = new System.Drawing.Size(271, 20);
            this.textBox_FilterMask.TabIndex = 5;
            this.textBox_FilterMask.Text = "c:\\Test*";
            // 
            // label6
            // 
            this.label6.AutoSize = true;
            this.label6.Location = new System.Drawing.Point(25, 67);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(58, 13);
            this.label6.TabIndex = 1;
            this.label6.Text = "Filter Mask";
            // 
            // label5
            // 
            this.label5.AutoSize = true;
            this.label5.Location = new System.Drawing.Point(25, 33);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(62, 13);
            this.label5.TabIndex = 0;
            this.label5.Text = "AccessFlag";
            // 
            // textBox_AccessFlag
            // 
            this.textBox_AccessFlag.Location = new System.Drawing.Point(187, 30);
            this.textBox_AccessFlag.Name = "textBox_AccessFlag";
            this.textBox_AccessFlag.Size = new System.Drawing.Size(271, 20);
            this.textBox_AccessFlag.TabIndex = 4;
            this.textBox_AccessFlag.Text = "65535";
            // 
            // textBox_ExcludePID
            // 
            this.textBox_ExcludePID.Location = new System.Drawing.Point(190, 103);
            this.textBox_ExcludePID.Name = "textBox_ExcludePID";
            this.textBox_ExcludePID.Size = new System.Drawing.Size(271, 20);
            this.textBox_ExcludePID.TabIndex = 7;
            // 
            // textBox_ConnectionTimeout
            // 
            this.textBox_ConnectionTimeout.Location = new System.Drawing.Point(190, 31);
            this.textBox_ConnectionTimeout.Name = "textBox_ConnectionTimeout";
            this.textBox_ConnectionTimeout.Size = new System.Drawing.Size(271, 20);
            this.textBox_ConnectionTimeout.TabIndex = 5;
            this.textBox_ConnectionTimeout.Text = "30";
            // 
            // label4
            // 
            this.label4.AutoSize = true;
            this.label4.Location = new System.Drawing.Point(28, 106);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(104, 13);
            this.label4.TabIndex = 3;
            this.label4.Text = "Excluded Process Id";
            // 
            // label3
            // 
            this.label3.AutoSize = true;
            this.label3.Location = new System.Drawing.Point(28, 140);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(94, 13);
            this.label3.TabIndex = 2;
            this.label3.Text = "Register Requests";
            // 
            // label2
            // 
            this.label2.AutoSize = true;
            this.label2.Location = new System.Drawing.Point(28, 11);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(56, 13);
            this.label2.TabIndex = 1;
            this.label2.Text = "Filter Type";
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(28, 34);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(153, 13);
            this.label1.TabIndex = 0;
            this.label1.Text = "Connection Timeout (Seconds)";
            // 
            // listView_FilterRules
            // 
            this.listView_FilterRules.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_FilterRules.FullRowSelect = true;
            this.listView_FilterRules.LabelEdit = true;
            this.listView_FilterRules.Location = new System.Drawing.Point(0, 0);
            this.listView_FilterRules.Name = "listView_FilterRules";
            this.listView_FilterRules.Size = new System.Drawing.Size(295, 486);
            this.listView_FilterRules.TabIndex = 0;
            this.listView_FilterRules.UseCompatibleStateImageBehavior = false;
            this.listView_FilterRules.View = System.Windows.Forms.View.Details;
            // 
            // button_ApplySetting
            // 
            this.button_ApplySetting.Location = new System.Drawing.Point(30, 216);
            this.button_ApplySetting.Name = "button_ApplySetting";
            this.button_ApplySetting.Size = new System.Drawing.Size(119, 23);
            this.button_ApplySetting.TabIndex = 5;
            this.button_ApplySetting.Text = "Apply Setting";
            this.button_ApplySetting.UseVisualStyleBackColor = true;
            this.button_ApplySetting.Click += new System.EventHandler(this.button_ApplySetting_Click);
            // 
            // button_RemoveFilter
            // 
            this.button_RemoveFilter.Location = new System.Drawing.Point(30, 130);
            this.button_RemoveFilter.Name = "button_RemoveFilter";
            this.button_RemoveFilter.Size = new System.Drawing.Size(119, 23);
            this.button_RemoveFilter.TabIndex = 4;
            this.button_RemoveFilter.Text = "Remove Filter Rule";
            this.button_RemoveFilter.UseVisualStyleBackColor = true;
            this.button_RemoveFilter.Click += new System.EventHandler(this.button_RemoveFilter_Click);
            // 
            // button_AddFilterRule
            // 
            this.button_AddFilterRule.Location = new System.Drawing.Point(30, 44);
            this.button_AddFilterRule.Name = "button_AddFilterRule";
            this.button_AddFilterRule.Size = new System.Drawing.Size(119, 23);
            this.button_AddFilterRule.TabIndex = 1;
            this.button_AddFilterRule.Text = "Add Filter Rule";
            this.button_AddFilterRule.UseVisualStyleBackColor = true;
            this.button_AddFilterRule.Click += new System.EventHandler(this.button_AddFilterRule_Click);
            // 
            // tabPage_Encryption
            // 
            this.tabPage_Encryption.Controls.Add(this.groupBox4);
            this.tabPage_Encryption.Controls.Add(this.groupBox2);
            this.tabPage_Encryption.Location = new System.Drawing.Point(4, 22);
            this.tabPage_Encryption.Name = "tabPage_Encryption";
            this.tabPage_Encryption.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_Encryption.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_Encryption.TabIndex = 4;
            this.tabPage_Encryption.Text = "Encryption Test";
            this.tabPage_Encryption.UseVisualStyleBackColor = true;
            // 
            // groupBox4
            // 
            this.groupBox4.Controls.Add(this.label16);
            this.groupBox4.Controls.Add(this.button_ApplyEncryptionSetting);
            this.groupBox4.Controls.Add(this.button_RemoveEncryptionFilterRule);
            this.groupBox4.Controls.Add(this.button_AddEncryptionFilterRule);
            this.groupBox4.Controls.Add(this.listView_EncryptFilterRule);
            this.groupBox4.Controls.Add(this.textBox_EncryptionFilterMask);
            this.groupBox4.Controls.Add(this.button1);
            this.groupBox4.Controls.Add(this.button2);
            this.groupBox4.Controls.Add(this.label10);
            this.groupBox4.Controls.Add(this.textBox_EncryptFilterRuleKey);
            this.groupBox4.Controls.Add(this.label11);
            this.groupBox4.Location = new System.Drawing.Point(541, 6);
            this.groupBox4.Name = "groupBox4";
            this.groupBox4.Size = new System.Drawing.Size(461, 478);
            this.groupBox4.TabIndex = 12;
            this.groupBox4.TabStop = false;
            this.groupBox4.Text = "Filter Driver Setting";
            // 
            // label16
            // 
            this.label16.AutoSize = true;
            this.label16.Location = new System.Drawing.Point(135, 37);
            this.label16.Name = "label16";
            this.label16.Size = new System.Drawing.Size(273, 13);
            this.label16.TabIndex = 12;
            this.label16.Text = "(It must be the same as the one used by encryption API))";
            // 
            // button_ApplyEncryptionSetting
            // 
            this.button_ApplyEncryptionSetting.Location = new System.Drawing.Point(344, 333);
            this.button_ApplyEncryptionSetting.Name = "button_ApplyEncryptionSetting";
            this.button_ApplyEncryptionSetting.Size = new System.Drawing.Size(98, 23);
            this.button_ApplyEncryptionSetting.TabIndex = 10;
            this.button_ApplyEncryptionSetting.Text = "Apply Setting";
            this.button_ApplyEncryptionSetting.UseVisualStyleBackColor = true;
            this.button_ApplyEncryptionSetting.Click += new System.EventHandler(this.button_ApplyEncryptionSetting_Click);
            // 
            // button_RemoveEncryptionFilterRule
            // 
            this.button_RemoveEncryptionFilterRule.Location = new System.Drawing.Point(344, 270);
            this.button_RemoveEncryptionFilterRule.Name = "button_RemoveEncryptionFilterRule";
            this.button_RemoveEncryptionFilterRule.Size = new System.Drawing.Size(111, 23);
            this.button_RemoveEncryptionFilterRule.TabIndex = 9;
            this.button_RemoveEncryptionFilterRule.Text = "Remove Filter Rule";
            this.button_RemoveEncryptionFilterRule.UseVisualStyleBackColor = true;
            this.button_RemoveEncryptionFilterRule.Click += new System.EventHandler(this.button_RemoveEncryptionFilterRule_Click);
            // 
            // button_AddEncryptionFilterRule
            // 
            this.button_AddEncryptionFilterRule.Location = new System.Drawing.Point(344, 207);
            this.button_AddEncryptionFilterRule.Name = "button_AddEncryptionFilterRule";
            this.button_AddEncryptionFilterRule.Size = new System.Drawing.Size(101, 23);
            this.button_AddEncryptionFilterRule.TabIndex = 8;
            this.button_AddEncryptionFilterRule.Text = "Add Filter Rule";
            this.button_AddEncryptionFilterRule.UseVisualStyleBackColor = true;
            this.button_AddEncryptionFilterRule.Click += new System.EventHandler(this.button_AddEncryptionFilterRule_Click);
            // 
            // listView_EncryptFilterRule
            // 
            this.listView_EncryptFilterRule.FullRowSelect = true;
            this.listView_EncryptFilterRule.LabelEdit = true;
            this.listView_EncryptFilterRule.Location = new System.Drawing.Point(9, 207);
            this.listView_EncryptFilterRule.Name = "listView_EncryptFilterRule";
            this.listView_EncryptFilterRule.Size = new System.Drawing.Size(329, 253);
            this.listView_EncryptFilterRule.TabIndex = 7;
            this.listView_EncryptFilterRule.UseCompatibleStateImageBehavior = false;
            this.listView_EncryptFilterRule.View = System.Windows.Forms.View.Details;
            // 
            // textBox_EncryptionFilterMask
            // 
            this.textBox_EncryptionFilterMask.Location = new System.Drawing.Point(145, 118);
            this.textBox_EncryptionFilterMask.Name = "textBox_EncryptionFilterMask";
            this.textBox_EncryptionFilterMask.Size = new System.Drawing.Size(297, 20);
            this.textBox_EncryptionFilterMask.TabIndex = 3;
            this.textBox_EncryptionFilterMask.Text = "c:\\EncryptFolder\\*";
            // 
            // button1
            // 
            this.button1.Location = new System.Drawing.Point(28, 437);
            this.button1.Name = "button1";
            this.button1.Size = new System.Drawing.Size(75, 23);
            this.button1.TabIndex = 4;
            this.button1.Text = "Encrypt File";
            this.button1.UseVisualStyleBackColor = true;
            // 
            // button2
            // 
            this.button2.Location = new System.Drawing.Point(178, 437);
            this.button2.Name = "button2";
            this.button2.Size = new System.Drawing.Size(75, 23);
            this.button2.TabIndex = 6;
            this.button2.Text = "Decrypt File";
            this.button2.UseVisualStyleBackColor = true;
            // 
            // label10
            // 
            this.label10.AutoSize = true;
            this.label10.Location = new System.Drawing.Point(6, 60);
            this.label10.Name = "label10";
            this.label10.Size = new System.Drawing.Size(133, 13);
            this.label10.TabIndex = 0;
            this.label10.Text = "Encryption Key(Hex String)";
            // 
            // textBox_EncryptFilterRuleKey
            // 
            this.textBox_EncryptFilterRuleKey.Location = new System.Drawing.Point(145, 57);
            this.textBox_EncryptFilterRuleKey.Name = "textBox_EncryptFilterRuleKey";
            this.textBox_EncryptFilterRuleKey.Size = new System.Drawing.Size(297, 20);
            this.textBox_EncryptFilterRuleKey.TabIndex = 1;
            this.textBox_EncryptFilterRuleKey.Text = "603deb1015ca71be2b73aef0857d77811f352c073b6108d72d9810a30914dff4";
            // 
            // label11
            // 
            this.label11.AutoSize = true;
            this.label11.Location = new System.Drawing.Point(6, 121);
            this.label11.Name = "label11";
            this.label11.Size = new System.Drawing.Size(89, 13);
            this.label11.TabIndex = 2;
            this.label11.Text = "Encryption Folder";
            // 
            // groupBox2
            // 
            this.groupBox2.Controls.Add(this.checkBox_RawHex);
            this.groupBox2.Controls.Add(this.button_DeleteIVTag);
            this.groupBox2.Controls.Add(this.checkBox_AddIVTag);
            this.groupBox2.Controls.Add(this.label15);
            this.groupBox2.Controls.Add(this.label14);
            this.groupBox2.Controls.Add(this.textBox_IV);
            this.groupBox2.Controls.Add(this.label13);
            this.groupBox2.Controls.Add(this.button_ReadEncryptedFile);
            this.groupBox2.Controls.Add(this.button_CopyEncryptedFile);
            this.groupBox2.Controls.Add(this.textBox_EncryptFileName);
            this.groupBox2.Controls.Add(this.button_EncryptFile);
            this.groupBox2.Controls.Add(this.button_DecryptFile);
            this.groupBox2.Controls.Add(this.label8);
            this.groupBox2.Controls.Add(this.textBox_EncryptionInfo);
            this.groupBox2.Controls.Add(this.textBox_EncryptKey);
            this.groupBox2.Controls.Add(this.label9);
            this.groupBox2.Location = new System.Drawing.Point(21, 6);
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.Size = new System.Drawing.Size(519, 478);
            this.groupBox2.TabIndex = 11;
            this.groupBox2.TabStop = false;
            this.groupBox2.Text = "File Test";
            // 
            // button_DeleteIVTag
            // 
            this.button_DeleteIVTag.Location = new System.Drawing.Point(411, 437);
            this.button_DeleteIVTag.Name = "button_DeleteIVTag";
            this.button_DeleteIVTag.Size = new System.Drawing.Size(90, 23);
            this.button_DeleteIVTag.TabIndex = 15;
            this.button_DeleteIVTag.Text = "DeleteIVTag";
            this.button_DeleteIVTag.UseVisualStyleBackColor = true;
            this.button_DeleteIVTag.Click += new System.EventHandler(this.button_DeleteIVTag_Click);
            // 
            // checkBox_AddIVTag
            // 
            this.checkBox_AddIVTag.AutoSize = true;
            this.checkBox_AddIVTag.Checked = true;
            this.checkBox_AddIVTag.CheckState = System.Windows.Forms.CheckState.Checked;
            this.checkBox_AddIVTag.Location = new System.Drawing.Point(151, 196);
            this.checkBox_AddIVTag.Name = "checkBox_AddIVTag";
            this.checkBox_AddIVTag.Size = new System.Drawing.Size(215, 17);
            this.checkBox_AddIVTag.TabIndex = 13;
            this.checkBox_AddIVTag.Text = "Add IV Tag To File ( used by filter driver)";
            this.checkBox_AddIVTag.UseVisualStyleBackColor = true;
            // 
            // label15
            // 
            this.label15.AutoSize = true;
            this.label15.Location = new System.Drawing.Point(152, 95);
            this.label15.Name = "label15";
            this.label15.Size = new System.Drawing.Size(333, 13);
            this.label15.TabIndex = 12;
            this.label15.Text = "(It must be 16 bytes, or let it empty, it will be assigned to an unique IV)";
            // 
            // label14
            // 
            this.label14.AutoSize = true;
            this.label14.Location = new System.Drawing.Point(148, 37);
            this.label14.Name = "label14";
            this.label14.Size = new System.Drawing.Size(250, 13);
            this.label14.TabIndex = 11;
            this.label14.Text = "(Encryption Key Length Must Be 16, 24 or 32 bytes)";
            // 
            // textBox_IV
            // 
            this.textBox_IV.Location = new System.Drawing.Point(151, 114);
            this.textBox_IV.Name = "textBox_IV";
            this.textBox_IV.Size = new System.Drawing.Size(352, 20);
            this.textBox_IV.TabIndex = 10;
            // 
            // label13
            // 
            this.label13.AutoSize = true;
            this.label13.Location = new System.Drawing.Point(7, 160);
            this.label13.Name = "label13";
            this.label13.Size = new System.Drawing.Size(54, 13);
            this.label13.TabIndex = 9;
            this.label13.Text = "File Name";
            // 
            // button_ReadEncryptedFile
            // 
            this.button_ReadEncryptedFile.Location = new System.Drawing.Point(313, 437);
            this.button_ReadEncryptedFile.Name = "button_ReadEncryptedFile";
            this.button_ReadEncryptedFile.Size = new System.Drawing.Size(90, 23);
            this.button_ReadEncryptedFile.TabIndex = 8;
            this.button_ReadEncryptedFile.Text = "ReadFileRaw";
            this.button_ReadEncryptedFile.UseVisualStyleBackColor = true;
            this.button_ReadEncryptedFile.Click += new System.EventHandler(this.button_ReadEncryptedFile_Click);
            // 
            // button_CopyEncryptedFile
            // 
            this.button_CopyEncryptedFile.Location = new System.Drawing.Point(193, 437);
            this.button_CopyEncryptedFile.Name = "button_CopyEncryptedFile";
            this.button_CopyEncryptedFile.Size = new System.Drawing.Size(111, 23);
            this.button_CopyEncryptedFile.TabIndex = 7;
            this.button_CopyEncryptedFile.Text = "CopyEncryptedFile";
            this.button_CopyEncryptedFile.UseVisualStyleBackColor = true;
            this.button_CopyEncryptedFile.Click += new System.EventHandler(this.button_CopyEncryptedFile_Click);
            // 
            // textBox_EncryptFileName
            // 
            this.textBox_EncryptFileName.Location = new System.Drawing.Point(151, 157);
            this.textBox_EncryptFileName.Name = "textBox_EncryptFileName";
            this.textBox_EncryptFileName.Size = new System.Drawing.Size(352, 20);
            this.textBox_EncryptFileName.TabIndex = 3;
            // 
            // button_EncryptFile
            // 
            this.button_EncryptFile.Location = new System.Drawing.Point(7, 437);
            this.button_EncryptFile.Name = "button_EncryptFile";
            this.button_EncryptFile.Size = new System.Drawing.Size(75, 23);
            this.button_EncryptFile.TabIndex = 4;
            this.button_EncryptFile.Text = "Encrypt File";
            this.button_EncryptFile.UseVisualStyleBackColor = true;
            this.button_EncryptFile.Click += new System.EventHandler(this.button_EncryptFile_Click);
            // 
            // button_DecryptFile
            // 
            this.button_DecryptFile.Location = new System.Drawing.Point(100, 437);
            this.button_DecryptFile.Name = "button_DecryptFile";
            this.button_DecryptFile.Size = new System.Drawing.Size(75, 23);
            this.button_DecryptFile.TabIndex = 6;
            this.button_DecryptFile.Text = "Decrypt File";
            this.button_DecryptFile.UseVisualStyleBackColor = true;
            this.button_DecryptFile.Click += new System.EventHandler(this.button_DecryptFile_Click);
            // 
            // label8
            // 
            this.label8.AutoSize = true;
            this.label8.Location = new System.Drawing.Point(3, 58);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(133, 13);
            this.label8.TabIndex = 0;
            this.label8.Text = "Encryption Key(Hex String)";
            // 
            // textBox_EncryptionInfo
            // 
            this.textBox_EncryptionInfo.Location = new System.Drawing.Point(10, 238);
            this.textBox_EncryptionInfo.Multiline = true;
            this.textBox_EncryptionInfo.Name = "textBox_EncryptionInfo";
            this.textBox_EncryptionInfo.ScrollBars = System.Windows.Forms.ScrollBars.Both;
            this.textBox_EncryptionInfo.Size = new System.Drawing.Size(493, 193);
            this.textBox_EncryptionInfo.TabIndex = 5;
            // 
            // textBox_EncryptKey
            // 
            this.textBox_EncryptKey.Location = new System.Drawing.Point(152, 53);
            this.textBox_EncryptKey.Name = "textBox_EncryptKey";
            this.textBox_EncryptKey.Size = new System.Drawing.Size(351, 20);
            this.textBox_EncryptKey.TabIndex = 1;
            this.textBox_EncryptKey.Text = "603deb1015ca71be2b73aef0857d77811f352c073b6108d72d9810a30914dff4";
            // 
            // label9
            // 
            this.label9.AutoSize = true;
            this.label9.Location = new System.Drawing.Point(5, 114);
            this.label9.Name = "label9";
            this.label9.Size = new System.Drawing.Size(120, 13);
            this.label9.TabIndex = 2;
            this.label9.Text = "Initial Vector(Hex String)";
            // 
            // tabPage_EncryptionUnitTest
            // 
            this.tabPage_EncryptionUnitTest.Controls.Add(this.groupBox5);
            this.tabPage_EncryptionUnitTest.Location = new System.Drawing.Point(4, 22);
            this.tabPage_EncryptionUnitTest.Name = "tabPage_EncryptionUnitTest";
            this.tabPage_EncryptionUnitTest.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_EncryptionUnitTest.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_EncryptionUnitTest.TabIndex = 5;
            this.tabPage_EncryptionUnitTest.Text = "Encryption UnitTest";
            this.tabPage_EncryptionUnitTest.UseVisualStyleBackColor = true;
            // 
            // groupBox5
            // 
            this.groupBox5.Controls.Add(this.button_StopEncryptionUnitTest);
            this.groupBox5.Controls.Add(this.button_EncryptionUnitTest);
            this.groupBox5.Controls.Add(this.textBox_EncryptionUnitTestInfo);
            this.groupBox5.Location = new System.Drawing.Point(8, 7);
            this.groupBox5.Name = "groupBox5";
            this.groupBox5.Size = new System.Drawing.Size(983, 478);
            this.groupBox5.TabIndex = 12;
            this.groupBox5.TabStop = false;
            // 
            // button_StopEncryptionUnitTest
            // 
            this.button_StopEncryptionUnitTest.Location = new System.Drawing.Point(789, 437);
            this.button_StopEncryptionUnitTest.Name = "button_StopEncryptionUnitTest";
            this.button_StopEncryptionUnitTest.Size = new System.Drawing.Size(174, 23);
            this.button_StopEncryptionUnitTest.TabIndex = 6;
            this.button_StopEncryptionUnitTest.Text = "Stop Encryption Unit Test";
            this.button_StopEncryptionUnitTest.UseVisualStyleBackColor = true;
            this.button_StopEncryptionUnitTest.Click += new System.EventHandler(this.button_StopEncryptionUnitTest_Click);
            // 
            // button_EncryptionUnitTest
            // 
            this.button_EncryptionUnitTest.Location = new System.Drawing.Point(28, 437);
            this.button_EncryptionUnitTest.Name = "button_EncryptionUnitTest";
            this.button_EncryptionUnitTest.Size = new System.Drawing.Size(174, 23);
            this.button_EncryptionUnitTest.TabIndex = 4;
            this.button_EncryptionUnitTest.Text = "Start Encryption Unit Test";
            this.button_EncryptionUnitTest.UseVisualStyleBackColor = true;
            this.button_EncryptionUnitTest.Click += new System.EventHandler(this.button_EncryptionUnitTest_Click);
            // 
            // textBox_EncryptionUnitTestInfo
            // 
            this.textBox_EncryptionUnitTestInfo.Location = new System.Drawing.Point(28, 19);
            this.textBox_EncryptionUnitTestInfo.Multiline = true;
            this.textBox_EncryptionUnitTestInfo.Name = "textBox_EncryptionUnitTestInfo";
            this.textBox_EncryptionUnitTestInfo.ScrollBars = System.Windows.Forms.ScrollBars.Both;
            this.textBox_EncryptionUnitTestInfo.Size = new System.Drawing.Size(935, 412);
            this.textBox_EncryptionUnitTestInfo.TabIndex = 5;
            // 
            // tabPage_EventLog
            // 
            this.tabPage_EventLog.Controls.Add(this.listView_Message);
            this.tabPage_EventLog.Location = new System.Drawing.Point(4, 22);
            this.tabPage_EventLog.Name = "tabPage_EventLog";
            this.tabPage_EventLog.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage_EventLog.Size = new System.Drawing.Size(1010, 492);
            this.tabPage_EventLog.TabIndex = 3;
            this.tabPage_EventLog.Text = "EventLog";
            this.tabPage_EventLog.UseVisualStyleBackColor = true;
            // 
            // listView_Message
            // 
            this.listView_Message.Activation = System.Windows.Forms.ItemActivation.OneClick;
            this.listView_Message.Dock = System.Windows.Forms.DockStyle.Fill;
            this.listView_Message.FullRowSelect = true;
            this.listView_Message.GridLines = true;
            this.listView_Message.HotTracking = true;
            this.listView_Message.HoverSelection = true;
            this.listView_Message.LabelEdit = true;
            this.listView_Message.Location = new System.Drawing.Point(3, 3);
            this.listView_Message.Name = "listView_Message";
            this.listView_Message.Size = new System.Drawing.Size(1004, 486);
            this.listView_Message.TabIndex = 0;
            this.listView_Message.UseCompatibleStateImageBehavior = false;
            this.listView_Message.View = System.Windows.Forms.View.Details;
            // 
            // checkBox_RawHex
            // 
            this.checkBox_RawHex.AutoSize = true;
            this.checkBox_RawHex.Checked = true;
            this.checkBox_RawHex.CheckState = System.Windows.Forms.CheckState.Checked;
            this.checkBox_RawHex.Location = new System.Drawing.Point(370, 196);
            this.checkBox_RawHex.Name = "checkBox_RawHex";
            this.checkBox_RawHex.Size = new System.Drawing.Size(131, 17);
            this.checkBox_RawHex.TabIndex = 16;
            this.checkBox_RawHex.Text = "ReadFileRawWithHex";
            this.checkBox_RawHex.UseVisualStyleBackColor = true;
            // 
            // FilterDemo
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(1018, 518);
            this.Controls.Add(this.TabPage);
            this.Name = "FilterDemo";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
            this.Text = "Filter Demo";
            this.TabPage.ResumeLayout(false);
            this.tabPage_FilterMessage.ResumeLayout(false);
            this.splitContainer1.Panel1.ResumeLayout(false);
            this.splitContainer1.Panel2.ResumeLayout(false);
            this.splitContainer1.ResumeLayout(false);
            this.groupBox1.ResumeLayout(false);
            this.tabPage_Setting.ResumeLayout(false);
            this.splitContainer3.Panel1.ResumeLayout(false);
            this.splitContainer3.Panel2.ResumeLayout(false);
            this.splitContainer3.ResumeLayout(false);
            this.splitContainer4.Panel1.ResumeLayout(false);
            this.splitContainer4.Panel1.PerformLayout();
            this.splitContainer4.Panel2.ResumeLayout(false);
            this.splitContainer4.ResumeLayout(false);
            this.groupBox3.ResumeLayout(false);
            this.groupBox3.PerformLayout();
            this.tabPage_Encryption.ResumeLayout(false);
            this.groupBox4.ResumeLayout(false);
            this.groupBox4.PerformLayout();
            this.groupBox2.ResumeLayout(false);
            this.groupBox2.PerformLayout();
            this.tabPage_EncryptionUnitTest.ResumeLayout(false);
            this.groupBox5.ResumeLayout(false);
            this.groupBox5.PerformLayout();
            this.tabPage_EventLog.ResumeLayout(false);
            this.ResumeLayout(false);

        }

        #endregion

        private System.Windows.Forms.TabControl TabPage;
        private System.Windows.Forms.TabPage tabPage_Setting;
        private System.Windows.Forms.TabPage tabPage_EventLog;
        private System.Windows.Forms.SplitContainer splitContainer3;
        private System.Windows.Forms.SplitContainer splitContainer4;
        private System.Windows.Forms.Button button_AddFilterRule;
        private System.Windows.Forms.TextBox textBox_ExcludePID;
        private System.Windows.Forms.TextBox textBox_ConnectionTimeout;
        private System.Windows.Forms.TextBox textBox_AccessFlag;
        private System.Windows.Forms.Label label4;
        private System.Windows.Forms.Label label3;
        private System.Windows.Forms.Label label2;
        private System.Windows.Forms.Label label1;
        private System.Windows.Forms.ListView listView_FilterRules;
        private System.Windows.Forms.GroupBox groupBox3;
        private System.Windows.Forms.Label label6;
        private System.Windows.Forms.Label label5;
        private System.Windows.Forms.ComboBox comboBox_FilterType;
        private System.Windows.Forms.Button button_AccessFlag;
        private System.Windows.Forms.TextBox textBox_FilterMask;
        private System.Windows.Forms.Button button_RemoveFilter;
        private System.Windows.Forms.TabPage tabPage_FilterMessage;
        private System.Windows.Forms.SplitContainer splitContainer1;
        private System.Windows.Forms.ListView listView_MessageInfo;
        private System.Windows.Forms.GroupBox groupBox1;
        private System.Windows.Forms.Button button_Clear;
        private System.Windows.Forms.Button button_Start;
        private System.Windows.Forms.Button button_Stop;
        private System.Windows.Forms.Button button_ExcludedPID;
        private System.Windows.Forms.Button button_ApplySetting;
        private System.Windows.Forms.ListView listView_Message;
        private System.Windows.Forms.TextBox textBox_ConnectionThreads;
        private System.Windows.Forms.Label label_ConnectionThreads;
        private System.Windows.Forms.Label label7;
        private System.Windows.Forms.TextBox textBox_ReparseMask;
        private System.Windows.Forms.Button button_RequestRegistration;
        private System.Windows.Forms.TextBox textBox_RequestRegistration;
        private System.Windows.Forms.Button button_UnInstallDriver;
        private System.Windows.Forms.Button button_InstallDriver;
        private TabPage tabPage_Encryption;
        private TextBox textBox_EncryptionInfo;
        private Button button_EncryptFile;
        private Button button_DecryptFile;
        private Label label12;
        private TextBox textBox_EncryptionKey;
        private GroupBox groupBox4;
        private TextBox textBox_EncryptionFilterMask;
        private Button button1;
        private Button button2;
        private Label label10;
        private TextBox textBox_EncryptFilterRuleKey;
        private Label label11;
        private GroupBox groupBox2;
        private TextBox textBox_EncryptFileName;
        private Label label8;
        private TextBox textBox_EncryptKey;
        private Label label9;
        private Button button_ApplyEncryptionSetting;
        private Button button_RemoveEncryptionFilterRule;
        private Button button_AddEncryptionFilterRule;
        private ListView listView_EncryptFilterRule;
        private Button button_CopyEncryptedFile;
        private Button button_ReadEncryptedFile;
        private TabPage tabPage_EncryptionUnitTest;
        private GroupBox groupBox5;
        private Button button_EncryptionUnitTest;
        private TextBox textBox_EncryptionUnitTestInfo;
        private Button button_StopEncryptionUnitTest;
        private Label label15;
        private Label label14;
        private TextBox textBox_IV;
        private Label label13;
        private Label label16;
        private CheckBox checkBox_AddIVTag;
        private Button button_DeleteIVTag;
        private Label label17;
        private CheckBox checkBox_RawHex;

    }
}

